@@ -151,6 +151,8 @@ class Crypto(object):
                 message = binascii.unhexlify(message)
             except Exception as e:
                 logger.error("could not get m: %s" % e)
+        elif isinstance(message, str):
+            message = message.encode('utf-8')
 
         if len(public_key) == 33:
             public_key = bitcoin.decompress(public_key)
@@ -220,4 +222,4 @@ class CryptoInstance():
         Returns:
             bool: True if verification passes. False otherwise.
         """
-        return Crypto.VerifySignature(message, signature, public_key, unhex=True)
+        return Crypto.VerifySignature(message, signature, public_key, unhex=unhex)
